@@ -8,16 +8,17 @@
 # check helper functions
 .onAttach <- function(libname, pkgname) {
   #
-  packageStartupMessage("\nInformation on this package and how to use it: \nhttps://github.com/rfhb/ctrdata/\n\n",
+  packageStartupMessage("Information on this package and how to use it:\n",
+                        "https://cran.r-project.org/package=ctrdata\n\n",
                         "Please respect the requirements and the copyrights of the\n",
                         "clinical trial registers when using their information. Call\n",
-                        "ctrOpenSearchPagesInBrowser(copyright = TRUE) and visit\n\n",
+                        "ctrOpenSearchPagesInBrowser(copyright = TRUE) and visit\n",
                         "https://www.clinicaltrialsregister.eu/disclaimer.html\n",
                         "https://clinicaltrials.gov/ct2/about-site/terms-conditions#Use\n"
   )
   #
   # check availabilities
-  packageStartupMessage("Testing helper binaries: ")
+  packageStartupMessage("Testing helper binaries:")
   #
   if (.Platform$OS.type == "windows") installCygwinWindowsTest()
   #
